{
    "$graph": [
        {
            "class": "Workflow",
            "label": "HS Metrics workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "record",
                            "name": "#labelled_file.yml/labelled_file",
                            "label": "a file with a label",
                            "fields": [
                                {
                                    "type": "File",
                                    "name": "#labelled_file.yml/labelled_file/file"
                                },
                                {
                                    "type": "string",
                                    "name": "#labelled_file.yml/labelled_file/label"
                                }
                            ]
                        }
                    ]
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#main/cram"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/minimum_mapping_quality"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#main/per_base_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#main/per_target_intervals"
                },
                {
                    "type": "string",
                    "id": "#main/reference"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#main/summary_intervals"
                }
            ],
            "steps": [
                {
                    "run": "#collect_hs_metrics.cwl",
                    "scatter": [
                        "#main/collect_per_base_hs_metrics/bait_intervals",
                        "#main/collect_per_base_hs_metrics/target_intervals",
                        "#main/collect_per_base_hs_metrics/output_prefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/per_base_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#main/collect_per_base_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#main/cram",
                            "id": "#main/collect_per_base_hs_metrics/cram"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#main/collect_per_base_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#main/minimum_base_quality",
                            "id": "#main/collect_per_base_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#main/minimum_mapping_quality",
                            "id": "#main/collect_per_base_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#main/per_base_intervals",
                            "valueFrom": "base-$(self.label)",
                            "id": "#main/collect_per_base_hs_metrics/output_prefix"
                        },
                        {
                            "default": true,
                            "id": "#main/collect_per_base_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": false,
                            "id": "#main/collect_per_base_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/collect_per_base_hs_metrics/reference"
                        },
                        {
                            "source": "#main/per_base_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#main/collect_per_base_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#main/collect_per_base_hs_metrics/hs_metrics",
                        "#main/collect_per_base_hs_metrics/per_base_coverage_metrics"
                    ],
                    "id": "#main/collect_per_base_hs_metrics"
                },
                {
                    "run": "#collect_hs_metrics.cwl",
                    "scatter": [
                        "#main/collect_per_target_hs_metrics/bait_intervals",
                        "#main/collect_per_target_hs_metrics/target_intervals",
                        "#main/collect_per_target_hs_metrics/output_prefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/per_target_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#main/collect_per_target_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#main/cram",
                            "id": "#main/collect_per_target_hs_metrics/cram"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#main/collect_per_target_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#main/minimum_base_quality",
                            "id": "#main/collect_per_target_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#main/minimum_mapping_quality",
                            "id": "#main/collect_per_target_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#main/per_target_intervals",
                            "valueFrom": "target-$(self.label)",
                            "id": "#main/collect_per_target_hs_metrics/output_prefix"
                        },
                        {
                            "default": false,
                            "id": "#main/collect_per_target_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": true,
                            "id": "#main/collect_per_target_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/collect_per_target_hs_metrics/reference"
                        },
                        {
                            "source": "#main/per_target_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#main/collect_per_target_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#main/collect_per_target_hs_metrics/hs_metrics",
                        "#main/collect_per_target_hs_metrics/per_target_coverage_metrics"
                    ],
                    "id": "#main/collect_per_target_hs_metrics"
                },
                {
                    "run": "#collect_hs_metrics.cwl",
                    "scatter": [
                        "#main/collect_summary_hs_metrics/bait_intervals",
                        "#main/collect_summary_hs_metrics/target_intervals",
                        "#main/collect_summary_hs_metrics/output_prefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/summary_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#main/collect_summary_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#main/cram",
                            "id": "#main/collect_summary_hs_metrics/cram"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#main/collect_summary_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#main/minimum_base_quality",
                            "id": "#main/collect_summary_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#main/minimum_mapping_quality",
                            "id": "#main/collect_summary_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#main/summary_intervals",
                            "valueFrom": "summary-$(self.label)",
                            "id": "#main/collect_summary_hs_metrics/output_prefix"
                        },
                        {
                            "default": false,
                            "id": "#main/collect_summary_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": false,
                            "id": "#main/collect_summary_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/collect_summary_hs_metrics/reference"
                        },
                        {
                            "source": "#main/summary_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#main/collect_summary_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#main/collect_summary_hs_metrics/hs_metrics"
                    ],
                    "id": "#main/collect_summary_hs_metrics"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/collect_per_base_hs_metrics/per_base_coverage_metrics",
                    "id": "#main/per_base_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/collect_per_base_hs_metrics/hs_metrics",
                    "id": "#main/per_base_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/collect_per_target_hs_metrics/per_target_coverage_metrics",
                    "id": "#main/per_target_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/collect_per_target_hs_metrics/hs_metrics",
                    "id": "#main/per_target_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/collect_summary_hs_metrics/hs_metrics",
                    "id": "#main/summary_hs_metrics"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "collect HS metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx32g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectHsMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.cram.nameroot).$(inputs.output_prefix)-HsMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 36000
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/picard-cwl:2.18.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "BAIT_INTERVALS="
                    },
                    "id": "#collect_hs_metrics.cwl/bait_intervals"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.crai"
                    ],
                    "id": "#collect_hs_metrics.cwl/cram"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_hs_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "prefix": "MINIMUM_BASE_QUALITY="
                    },
                    "id": "#collect_hs_metrics.cwl/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "prefix": "MINIMUM_MAPPING_QUALITY="
                    },
                    "id": "#collect_hs_metrics.cwl/minimum_mapping_quality"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "out",
                    "id": "#collect_hs_metrics.cwl/output_prefix"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "PER_BASE_COVERAGE=",
                        "valueFrom": "${\n    if(self) {\n        return inputs.cram.nameroot + \".\" + inputs.output_prefix + \"-PerBaseCoverage.txt\"\n    } else {\n        return false;\n    }\n}\n"
                    },
                    "id": "#collect_hs_metrics.cwl/per_base_coverage"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "PER_TARGET_COVERAGE=",
                        "valueFrom": "${\n    if(self) {\n        return inputs.cram.nameroot + \".\" + inputs.output_prefix + \"-PerTargetCoverage.txt\"\n    } else {\n        return false;\n    }\n}\n"
                    },
                    "id": "#collect_hs_metrics.cwl/per_target_coverage"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "R="
                    },
                    "id": "#collect_hs_metrics.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "TARGET_INTERVALS="
                    },
                    "id": "#collect_hs_metrics.cwl/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.cram.nameroot).$(inputs.output_prefix)-HsMetrics.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/hs_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.cram.nameroot).$(inputs.output_prefix)-PerBaseCoverage.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/per_base_coverage_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.cram.nameroot).$(inputs.output_prefix)-PerTargetCoverage.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/per_target_coverage_metrics"
                }
            ],
            "id": "#collect_hs_metrics.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
